InetSocketAddress

Struct InetSocketAddress 

pub struct InetSocketAddress(/* private fields */);
java.net.InetSocketAddress

Implementations

Source

impl InetSocketAddress

pub fn as_socket_address(&self, e: &mut Env<'_>) -> SocketAddress

Downcast self to SocketAddress

pub fn from_socket_address(e: &mut Env<'_>, addr: SocketAddress) -> Self

Upcast SocketAddress to self

pub fn new_wildcard_address(e: &mut Env<'_>, port: i32) -> Self

Create a new socket address, using the local wildcard address as the IP address

<https://docs.oracle.com/en/java/javase/19/docs/api/java.base/java/net/InetSocketAddress.html#(int)>

pub fn new_resolved(e: &mut Env<'_>, host: impl ToString, port: i32) -> Self

Create a new socket address, resolving the hostname to an IP address (unless the string is an IP literal)

https://docs.oracle.com/en/java/javase/19/docs/api/java.base/java/net/InetSocketAddress.html#%3Cinit%3E(java.lang.String,int)

pub fn new(e: &mut Env<'_>, addr: InetAddress, port: i32) -> Self

Create a new socket address from a known IP and port

<https://docs.oracle.com/en/java/javase/19/docs/api/java.base/java/net/InetSocketAddress.html#(java.net.InetAddress,int)>

pub fn address(&self, e: &mut Env<'_>) -> InetAddress

Get the IP address

pub fn port(&self, e: &mut Env<'_>) -> u16

Get the port

pub fn to_std(&self, e: &mut Env<'_>) -> SocketAddr

Convert InetSocketAddress to std::net::SocketAddr

pub fn to_no_std(&self, e: &mut Env<'_>) -> SocketAddr

Convert InetSocketAddress to no_std_net::SocketAddr

pub fn from_std(e: &mut Env<'_>, addr: SocketAddr) -> Self

Convert std::net::SocketAddr to InetSocketAddress

pub fn from_no_std(e: &mut Env<'_>, addr: SocketAddr) -> Self

Convert std::net::SocketAddr to InetSocketAddress