ByteBuffer

Struct ByteBuffer 

pub struct ByteBuffer(/* private fields */);
java.nio.ByteBuffer

Implementations

Source

impl ByteBuffer

pub fn new(e: &mut Env<'_>, bytes: impl IntoIterator<Item = u8>) -> Self

java.nio.ByteBuffer.wrap(byte[])

pub fn from_buf(buf: Buffer) -> Self

Upcast Buffer to ByteBuffer

pub fn as_buf(&self, e: &mut Env<'_>) -> Buffer

Downcast self to Buffer (superclass of ByteBuffer)

pub fn len(&self, e: &mut Env<'_>) -> u32

java.nio.Buffer.capacity()

pub fn rewind(&self, e: &mut Env<'_>)

java.nio.ByteBuffer.rewind()

pub fn position(&self, e: &mut Env<'_>) -> u32

java.nio.Buffer.position()

pub fn write_to( &self, e: &mut Env<'_>, start: usize, end: usize, buf: &mut [u8], ) -> usize

Write the contents of this byte buffer to a rust buffer

pub fn to_vec(&self, e: &mut Env<'_>) -> Vec<u8>

Extract the contents of this byte buffer to a vec of bytes